@@ -19,6 +19,8 @@ class ObjectClassifier():
         """
         self.FEATURE_SPECIFICATION_KEY = "feature_specification = "
 
+        self._data = {}
+
         self.classifier = TableRowClassifier(
             opencl_filename=opencl_filename,
             max_depth=max_depth,
@@ -69,6 +71,7 @@ class ObjectClassifier():
 
         selected_features, _ = self._make_features(self.classifier.feature_specification, labels, None, image)
         output = self.classifier.predict(selected_features, return_numpy=False)
+        self._data["APOC_ObjectClassifier_CLUSTER_ID"] = np.asarray(output)[0]
 
         # set background to zero
         cle.set_column(output, 0, 0)
@@ -175,14 +178,20 @@ class ObjectClassifier():
         Returns
         -------
         result:list[vector]
-            list of vectors corresponding to the requested features. The vectors are shaped (n) for n labels that
-            were annotated. Labels without annotation are removed from the vectors.
-            Background measurements are removed, because background cannot be classified.
+            list of vectors corresponding to the requested features.
+            If ground_truth is not None:
+                The vectors are shaped (n) for n labels that were annotated. Labels without annotation
+                are removed from the vectors. Background measurements are removed,
+                because background cannot be classified.
+            If ground_truth is None:
+                The vectors are shaped (n+1) for n labels.
+                That is, background + n measurements for n labels.
         ground_truth: ndimage
             selected elements of provided ground truth where it's not 0
         """
         import pyclesperanto_prototype as cle
         result = {}
+        self._data = {}
         touch_matrix = None
         distance_matrix = None
         mask = None
@@ -212,11 +221,14 @@ class ObjectClassifier():
                     result[key] = np.asarray([vector[mask]])
                 else:
                     result[key] = np.asarray([vector])
+                self._data[key] = result[key][0]
                 # print(key, result[-1])
 
         if ground_truth is not None:
+            self._data['label'] = all_features['label'][mask]
             return result, ground_truth[mask]
         else:
+            self._data['label'] = all_features['label']
             return result, None
 
     def statistics(self):
